cd "R:\Milner\Milner\regionalism book\results"
cd "chapter4\results"


clear all
macro drop _all
set mem 600m
use ..\..\Data\dyadicdata.dta

*  set all locals.
local theory "polconiiiA polity2_04"
local all "llntradenew llnGDP_gled08 ldGDP_gled08V2 lnewgatt ptadum_new llnGDPratio_g"
local atop "larmconflict latopally"
local cow "lally_new ldispute_new"
local regfe "fmrcol_new lndistance lheg_new onsetperc2 lcontig_new pcw89" 
local dyadfe "lheg_new onsetperc2 pcw89"
local spline "nohs2_ptaonsp*_r2"

logit nohs_rat2_onset2 `theory' `all' `atop' `regfe' `spline' i.region , vce(cl dyadid)
gen sample = e(sample)
logit nohs_rat2_onset2 polity2_04 `all' `atop' `regfe' `spline' i.region , vce(cl dyadid)

//  #1
//  tbl 4.1 -- descriptive stats

su nohs_rat2_onset2 `theory' checks `all' `atop' `cow' `regfe' /// 
	lregptaperc ltradepartpta lGATTrd llastGATT ls3uni dem17 cheibdemA xrB less_xconst_pol comm lcontagion lcontag_2 ///
	if year > 1951 & year <= 2004 , ///
	sep(0)

corr polconiiiA polity2_04 if year > 1951 & year <= 2004

corr polconiiiA checks if year > 1951 & year <= 2004

tab nohs_pta_rat2 if year==2005 /* p 111 */

//  tbl 4.2 

*  col 1: base model (polcon 1950-2005)
eststo : logit nohs_rat2_onset2 `theory' `all' `atop' `regfe' `spline' i.region , vce(cl dyadid)

*  col 2: dyadFE
eststo : xtlogit nohs_rat2_onset2 `theory' `all' `atop' `dyadfe' , fe

*** NUMBER OF DYAD PAIRS NOT FORMING PTA (p. 158)
*** NUMBER OF GROUPS DROPPED FROM DYAD FE/NUMBER OF GROUPS IN BASE MODEL

di 27110/32307 /* p 112 */

*  col 3: dyadyrFE
eststo : xtlogit nohs_rat2_onset2 `theory' `all' `atop'  i.year , fe

*  col 4: base model (polcon 1950-2005), `theory' vars also t-1

	*  create tmp lag theory vars for tbl output
	qui clonevar tmppolconiiiA = polconiiiA
	qui clonevar tmppolity2_04 = polity2_04
	qui replace polconiiiA = l.tmppolconiiiA
	qui replace polity2_04 = l.tmppolity2_04

eststo : logit nohs_rat2_onset2 `theory' `all' `atop' `regfe' `spline' i.region , vce(cl dyadid)
	drop polconiiiA polity2_04
	renvars tmppolconiiiA tmppolity2_04 , predrop(3)

*  col 5: base model (polcon 1950-2001)
eststo : logit nohs_rat2_onset2 `theory' `all' `cow' `regfe' `spline' i.region , vce(cl dyadid)


*  output tbl 4.2
esttab using ch4tbl42.csv, replace /// 
	b(3) se(3) scalars("N N" "N_clust Clusters" "ll Log-likelihood") sfmt(%12.0f %12.0f %12.3f) obslast  ///
	star(* .1 ** .05 *** .01) ///
	title(Table 4.2. polcon, region/dyad/dyad-yr fixed effects) ///
	mtitle("Base model" "Dyadic fixed effects" "Dyad&year fixed effects" "All variables lagged t-1" "COW alliance/MID") nonumbers nodepvars ///
	label coeflabels(2.region "South Asia" 3.region "Middle East & North Africa" 4.region "Sub-Saharan Africa" 5.region "Europe & Central Asia" /// 
		6.region "Latin America & Carib." 7.region "North/Central America" 8.region "Western Europe") ///
	order(polity2_04 polconiiiA ptadum_new llntradenew llnGDP_gled08 ldGDP_gled08V2 larmconflict /// 
		ldispute_new latopally lally_new fmrcol_new lcontig_new lndistance lheg_new pcw89 llnGDPratio_g /// 
		onsetperc2 lnewgatt) 
		
eststo clear

//  tbl 4.3 

*  col 1: base model with checks (1950-2005)
eststo : logit nohs_rat2_onset2 checks polity2_04 `all' `atop' `regfe' `spline' i.region , vce(cl dyadid)

*  col 2: polcon + xrB
eststo : logit nohs_rat2_onset2 polconiiiA xrB `all' `atop' `regfe' `spline' i.region , vce(cl dyadid)

di "States holding competitive election " exp(_b[xrB])-1 " more likely to ratify" /* p. 114 */
*  col 3: polcon + xrB + polity, dyad-yr fe
eststo : xtlogit nohs_rat2_onset2 polconiiiA xrB polity2_04 `all' `atop' i.year , fe

*  col 4: polcon + alternative polity score
eststo : logit nohs_rat2_onset2 polconiiiA less_xconst_pol `all' `atop' `regfe' `spline' i.region , vce(cl dyadid)

*  col 5: polcon + dem dummy
eststo : logit nohs_rat2_onset2 polconiiiA dem17 `all' `atop' `regfe' `spline' i.region , vce(cl dyadid)

*  col 6: polcon + ACLP
eststo : logit nohs_rat2_onset2 polconiiiA cheibdemA `all' `atop' `regfe' `spline' i.region , vce(cl dyadid)

*  col 7: polcon + no EC/EU
eststo : logit nohs_rat2_onset2 `theory' `all' `atop' `regfe' `spline' i.region if eurat2 == 0 , vce(cl dyadid)

* col 8: no EC/EU countries
eststo : logit nohs_rat2_onset2 `theory' `all' `atop' `regfe' `spline' i.region if eu1==0 & eu2==0  , vce(cl dyadid)

*  col 9: polcon + rare event
eststo : xi: relogit nohs_rat2_onset2 `theory' `all' `atop' `regfe' `spline' i.region , cluster(dyadid)

*  col 10: polcon + only 1st PTA in dyads
preserve
	drop if ptadum_new == 1
	eststo : logit nohs_rat2_onset2 `theory' `all' `atop' `regfe' `spline' i.region , vce(cl dyadid)
restore

*  col 11: base model (= col 1) with trade = 0 or missing removed.
eststo : logit nohs_rat2_onset2 polconiiiA polity2_04 `all' `atop' `regfe' `spline' i.region ///
	if l.trade > 0 & !missing(l.trade), vce(cl dyadid)

* col 12: other do file
	
*  output tbl 4.3
esttab using ch4tbl43.csv, replace /// 
	b(3) se(3) scalars("N N" "N_clust Clusters" "ll Log-likelihood") sfmt(%12.0f %12.0f %12.3f) obslast  ///
	star(* .1 ** .05 *** .01) ///
	title(Table 4.3. polcon, various region fixed effects) ///
	mtitle("Checks" "Comp Election" "Comp Elec + Polity" "Alt Polity" "Dem dummy" "ACLP" "VP Residuals" "No EC/EU join" "No EC/EU country" "Rare Event" "1st PTA" "W/O trade=0") ///
	nonumbers nodepvars ///
	label coeflabels(2.region "South Asia" 3.region "Middle East & North Africa" 4.region "Sub-Saharan Africa" 5.region "Europe & Central Asia" /// 
		6.region "Latin America & Carib." 7.region "North/Central America" 8.region "Western Europe") ///
	drop(nohs2_ptaonsp*_r2) ///
	order(polconiiiA checks vpresid polity2_04 xrB less_xconst_pol dem17 cheibdemA ptadum_new llntradenew llnGDP_gled08 ldGDP_gled08V2 larmconflict /// 
		latopally fmrcol_new lcontig_new lndistance lheg_new pcw89 llnGDPratio_g onsetperc2 lnewgatt) 

eststo clear
drop _Iregion*


//  tbl 4.4 

*  col 1: Region PTA
eststo : logit nohs_rat2_onset2 `theory' `all' `atop' `regfe' lregptaperc `spline' i.region , vce(cl dyadid)

*  col 2: Trade partners PTA, polcon
eststo : logit nohs_rat2_onset2 `theory' `all' `atop' `regfe' ltradepartpta `spline' i.region , vce(cl dyadid)

*  col 3: GATT round in progress
eststo : logit nohs_rat2_onset2 `theory' `all' `atop' `regfe' lGATTrd `spline' i.region , vce(cl dyadid)

*  col 4: Time since last GATT round completed
eststo : logit nohs_rat2_onset2 `theory' `all' `atop' `regfe' llastGATT `spline' i.region , vce(cl dyadid)

*  col 5: UN Score (COW ALLY & MIDs)
eststo : logit nohs_rat2_onset2 `theory' `all' `atop' `regfe' ls3uni `spline' i.region , vce(cl dyadid)

*  col 6: communist
eststo : logit nohs_rat2_onset2 `theory' `all' `atop' `regfe' comm `spline' i.region , vce(cl dyadid)

* Column 7: contagion + contagion^2
eststo : logit nohs_rat2_onset2 `theory' `all' `atop' `regfe' lcontagion lcontag_2  `spline' i.region if ptadum_new==0 , r cl(dyadid)
est store mod11 

*  output tbl 4.4
esttab using ch4tbl44.csv, replace /// 
	b(3) se(3) scalars("N N" "N_clust Clusters" "ll Log-likelihood") sfmt(%12.0f %12.0f %12.3f) obslast  ///
	star(* .1 ** .05 *** .01) ///
	title(Table 4.4. polcon, various region fixed effects) ///
	mtitle("Region PTA" "Trade partner PTA" "GATT round in progress" "Time since last GATT" "UN score" "Communist" "Contagion") nonumbers nodepvars ///
	label coeflabels(2.region "South Asia" 3.region "Middle East & North Africa" 4.region "Sub-Saharan Africa" 5.region "Europe & Central Asia" /// 
		6.region "Latin America & Carib." 7.region "North/Central America" 8.region "Western Europe") ///
	drop(nohs2_ptaonsp*_r2 1b.region) ///
	order(polconiiiA polity2_04 lregptaperc ltradepartpta lGATTrd llastGATT ls3uni comm lcontagion lcontag_2 ptadum_new llntradenew /// 
		llnGDP_gled08 ldGDP_gled08V2 larmconflict latopally fmrcol_new lcontig_new lndistance lheg_new pcw89 /// 
		llnGDPratio_g onsetperc2 lnewgatt) 

eststo clear

* pta_ch4tbl42V3.csv pta_ch4tbl43V3.csv pta_ch4tbl44V3.csv are put together into pta_ch4tbl4V3.xls.


preserve
tab region, gen(_ireg)
logit nohs_rat2_onset2 polconiiiA polity2_04 llntradenew llnGDP_gled08 ldGDP_gled08 larmconflict latopally fmrcol_new lcontig_new lndistance lheg_new lnewgatt ptadum_new onsetperc2 pcw89 llnGDPratio_g nohs2_ptaonsp*_r2 _ireg2 _ireg3 _ireg4 _ireg5 _ireg6 _ireg7 _ireg8  , r cl(dyadid)
keep if e(sample)
set seed 20309
keep dyadid year nohs_rat2_onset2 region nohs2_ptaonsp* polconiiiA polity2_04  llntradenew llnGDP_gled08 ldGDP_gled08 larmconflict latopally fmrcol_new lcontig_new lndistance lheg_new lnewgatt ptadum_new onsetperc2 pcw89 llnGDPratio_g
tab region, gen(_ireg)

estsimp logit nohs_rat2_onset2 polconiiiA polity2_04 llntradenew llnGDP_gled08 ldGDP_gled08 larmconflict latopally fmrcol_new lcontig_new lndistance lheg_new lnewgatt ptadum_new onsetperc2 pcw89 llnGDPratio_g nohs2_ptaonsp*_r2 _ireg2 _ireg3 _ireg4 _ireg5 _ireg6 _ireg7 _ireg8  , r cl(dyadid)
gen prob = .
gen probhi = .
gen problo =.
gen pol_val = .
gen double polcon_val = .

setx larmconflict 0 latopally 0 fmrcol_new 0 lcontig_new 0 lnewgatt 0 pcw89 1  _ireg2 0 _ireg3 0 _ireg4 0 _ireg5 0 _ireg6 0 _ireg7 0 _ireg8 0 ptadum_new 0
setx llntradenew median llnGDP_gled08 median ldGDP_gled08 median llnGDPratio_g median lndistance median lheg_new median nohs2_ptaonspl_r2 median nohs2_ptaonsp1_r2 median nohs2_ptaonsp2_r2 median nohs2_ptaonsp3_r2 median onsetperc2 median
setx polconiiiA median
local k = 1 
forval i = 1/21 {
replace pol_val = `i' if _n==`k'
setx polity2_04 `i'
simqi, prval(1) genpr(simpr1)
qui summ simpr1 , d
local simpr1 = r(mean)
replace prob = `simpr1' if _n==`k'
replace probhi= r(p95) if _n==`k'
replace problo = r(p5) if _n==`k'
drop simpr1
local k = `k'+1
}

line  prob pol_val , lcolor(red) || line  probhi pol_val , lpattern(dash) lcolor(black) || line  problo pol_val , lpattern(dash) lcolor(black) ,  ///
 ytitle("Probability of ratification", size(medium)) xtitle("Regime Type") ylabel(.0015(.0005).004) legend(off) /// 
 xlabel(1(5)21)  saving(figure41.gph, replace)


 replace prob = .
 replace probhi = .
 replace problo = .
local k = 1 

setx polity2_04 median
forval num = 0(.1).7 {
setx polconiiiA `num' 
replace polcon_val = `num' if _n==`k'
simqi, prval(1) genpr(simpr1)
qui summ simpr1 , d
local simpr1 = r(mean)
replace prob = `simpr1' if _n==`k'
replace probhi= r(p95) if _n==`k'
replace problo = r(p5) if _n==`k'
drop simpr1
local k = `k'+1
}
 
line  prob polcon_val , lcolor(red) || line  probhi polcon_val , lpattern(dash) lcolor(black) || line  problo polcon_val , lpattern(dash) lcolor(black) ,  ///
 ytitle("Probability of ratification", size(medium)) xtitle("Veto Players") ylabel(.001(.0005).003) legend(off) /// 
 xlabel(0(.1).7) saving(figure42.gph, replace)

 
  *** RELATIVE RISKS
 drop prob
gen prob =.
gen probp10 = .
gen probp90 = .
gen p10val= .
gen p90val = .

setx larmconflict 0 latopally 0 fmrcol_new 0 lcontig_new 0 lnewgatt 0 pcw89 1  _ireg2 0 _ireg3 0 _ireg4 0 _ireg5 0 _ireg6 0 _ireg7 0 _ireg8 0 ptadum_new 0
setx llntradenew median llnGDP_gled08 median ldGDP_gled08 median llnGDPratio_g median lndistance median lheg_new median nohs2_ptaonspl_r2 median nohs2_ptaonsp1_r2 median nohs2_ptaonsp2_r2 median nohs2_ptaonsp3_r2 median onsetperc2 median
setx polconiiiA median  polity2_04 median

gen varname = ""
local k = 1
foreach var of varlist polconiiiA polity2_04 lheg_new onsetperc2 llnGDP_gled08 llntradenew ldGDP_gled08 lndistance llnGDPratio_g   {
replace varname = "`var'" if _n==`k'
qui summ `var' ,d

replace p10val = r(p10) if _n==`k'
replace p90val = r(p90) if _n==`k'
if "`var'"=="polity2_04" {
replace p10val = 3 if _n==`k'
replace p90val = 19 if _n==`k'
}



setx `var' p10
simqi , prval(1) genpr(simprob)
summ simprob
replace probp10 = r(mean) if _n==`k'
drop simprob
setx `var' p90
simqi , prval(1) genpr(simprob)
summ simprob
replace probp90 = r(mean) if _n==`k'
drop simprob

local k = `k'+1
setx larmconflict 0 latopally 0 fmrcol_new 0 lcontig_new 0 lnewgatt 0 pcw89 1  _ireg2 0 _ireg3 0 _ireg4 0 _ireg5 0 _ireg6 0 _ireg7 0 _ireg8 0 ptadum_new 0
setx llntradenew median llnGDP_gled08 median ldGDP_gled08 median llnGDPratio_g median lndistance median lheg_new median nohs2_ptaonspl_r2 median nohs2_ptaonsp1_r2 median nohs2_ptaonsp2_r2 median nohs2_ptaonsp3_r2 median onsetperc2 median
setx polconiiiA median  polity2_04 median

}


foreach var of varlist pcw89 latopally lnewgatt fmrcol_new lcontig_new ptadum_new larmconflict  {

replace varname = "`var'" if _n==`k'

setx `var' 0
simqi , prval(1) genpr(simprob)
summ simprob
replace probp10 = r(mean) if _n==`k'
drop simprob
setx `var' 1
simqi , prval(1) genpr(simprob)
summ simprob

replace probp90 = r(mean) if _n==`k'

drop simprob
local k = `k'+1
setx larmconflict 0 latopally 0 fmrcol_new 0 lcontig_new 0 lnewgatt 0 pcw89 1  _ireg2 0 _ireg3 0 _ireg4 0 _ireg5 0 _ireg6 0 _ireg7 0 _ireg8 0 ptadum_new 0
}

setx polity2_04 3
simqi , prval(1) genpr(simprob)
summ simprob
replace probp10 = r(mean) if _n==2
drop simprob
setx polity2_04 19
simqi , prval(1) genpr(simprob)
summ simprob

replace probp90 = r(mean) if _n==2
drop simprob

gen varval = .
replace varval = 1 if varname=="polity2_04"
replace varval = 2 if varname=="polconiiiA"
replace varval = 3 if varname=="pcw89"
replace varval = 4 if varname=="onsetperc"
replace varval = 5 if varname=="lnewgatt"
replace varval = 6 if varname=="llnGDP_gled08"
replace varval = 7 if varname=="lheg_new"
replace varval = 8 if varname=="latopally"
replace varval = 9 if varname=="llntradenew"
replace varval = 10 if varname=="ldGDP_gled08"
replace varval = 11 if varname=="lndistance"
replace varval = 12 if varname=="llnGDPratio_g"
replace varval = 13 if varname=="fmrcol_new"
replace varval = 14 if varname=="lcontig_new"
replace varval = 15 if varname=="ptadum_new"
replace varval = 16 if varname=="larmconflict"


capture drop label define
label define list5 1 "Polity" 2 "Political constraints" 3 "Post Cold War" 4 "% dyads ratifying PTA" 5 "GATT/WTO" /*
 */ 6 "Log GDP" 7 "Hegemony" 8 "Alliance (ATOP)" 9 "Trade AB" 10 "dGDP A" 11 "Log of distance" 12 "Log GDP ratio" /*
 */ 13 "Former colony" 14 "Contiguity" 15 "Existing dyadic PTA" 16 "PRIO armed conflict"
 label val varval list5
gen relrisk = probp90/probp10 if probp90>probp10
replace relrisk = probp10/probp90 if probp90<probp10
 
 gen ptasp10=probp10*32307
 gen ptap90 = probp90*32307
 
 ** Pp 108-109
di "The relative risk of moving Polity from 3 to 19 is " relrisk[2]-1
di "The number of PTAs ratified when Polity==19 is " ptap90[2]
di "The number of PTAs ratified when Polity==3 is " ptasp10[2]

 di "The relative risk of moving polcon from 90% to 10% is " relrisk[1]-1
 
 list varval relrisk if varval~=. 
 
restore


*** Relative risks - checks
preserve
tab region, gen(_ireg)
logit nohs_rat2_onset2 checks polity2_04 llntradenew llnGDP_gled08 ldGDP_gled08 larmconflict latopally fmrcol_new lcontig_new lndistance lheg_new lnewgatt ptadum_new onsetperc2 pcw89 llnGDPratio_g nohs2_ptaonsp*_r2 _ireg2 _ireg3 _ireg4 _ireg5 _ireg6 _ireg7 _ireg8  , r cl(dyadid)
keep if e(sample)
set seed 20309
keep dyadid year nohs_rat2_onset2 region nohs2_ptaonsp* checks polity2_04  llntradenew llnGDP_gled08 ldGDP_gled08 larmconflict latopally fmrcol_new lcontig_new lndistance lheg_new lnewgatt ptadum_new onsetperc2 pcw89 llnGDPratio_g
tab region, gen(_ireg)

estsimp logit nohs_rat2_onset2 checks polity2_04 llntradenew llnGDP_gled08 ldGDP_gled08 larmconflict latopally fmrcol_new lcontig_new lndistance lheg_new lnewgatt ptadum_new onsetperc2 pcw89 llnGDPratio_g nohs2_ptaonsp*_r2 _ireg2 _ireg3 _ireg4 _ireg5 _ireg6 _ireg7 _ireg8  , r cl(dyadid)
setx larmconflict 0 latopally 0 fmrcol_new 0 lcontig_new 0 lnewgatt 0 pcw89 1  _ireg2 0 _ireg3 0 _ireg4 0 _ireg5 0 _ireg6 0 _ireg7 0 _ireg8 0 ptadum_new 0
setx llntradenew median llnGDP_gled08 median ldGDP_gled08 median llnGDPratio_g median lndistance median lheg_new median nohs2_ptaonspl_r2 median nohs2_ptaonsp1_r2 median nohs2_ptaonsp2_r2 median nohs2_ptaonsp3_r2 median onsetperc2 median
setx checks median  polity2_04 median


setx checks p10
simqi , prval(1) genpr(simprob)
summ simprob
scalar probp10 = r(mean) 
drop simprob
setx checks p90
simqi , prval(1) genpr(simprob)
summ simprob
scalar probp90 = r(mean) 
drop simprob
di "Country with few checks about " (probp10/probp90 -1)*100 "% more likely to ratify than one with many checks" /* p 113 */
restore
