
clear all

cd "R:\Milner\Milner\regionalism book\results"
cd "chapter5\results"

use "..\..\Data\ch5_surv.dta", clear

/******* Gen var for leaders leaving office prior to one year **********/
gen exit1=tenure<1 & exit==1 & pta_sign~=.

/*********************** Replication of BDM2S2 ************************/
/************************* USING  ARCHIGOS ****************************/
/************** See Logic of Political Survival p. 299 ****************/

streg W, dist(weib) cluster(ccode) anc(W) nolog
est store model1_bdm


/**********************************************************************/
/**************************  Kaplan Meier  ****************************/
/**********************************************************************/

****** DEMOCRACIES *****

sts graph if democ_polity==1, by(pta_sign) plot1opts(lpattern(dash) lcolor(gs6)) plot2opts(lpattern(solid) lcolor(gs12)) tmax(8) /*
*/  saving("figure51.gph", replace) xtitle("Tenure in office(Years)", size(small))  /*
*/ ytitle("Proportion of Leaders Remaining in Office", size(small)) legend(bexpand label(1 "Not Signing PTA") label(2 "Signing a PTA (in current or prev. yrs)") size(small))


/**********************************************************************/
/********** Replication of Weibull and Exponential Models *************/
/************           See also BDM2S2 p. 299       ******************/
/**********************************************************************/

***** Model 1 (Democracies) T5.1, Col. 2 *****

streg pta_sign if democ_polity==1, dist(weib) cluster(ccode) anc(pta_sign) nolog nohr
est store model1_col2_dem

/**********************************************************************/

***** Model 1 (Democracies) T5.1, Col. 3 *****
streg W pta_sign if democ_polity==1, dist(weib) cluster(ccode) nolog anc(pta_sign W) 
est store model1_col3_dem 

/**********************************************************************/

***** Model 1 (Democracies) T5.1, Col. 4 *****
streg W pta_sign S if democ_polity==1, dist(weib) cluster(ccode) nolog anc(pta_sign W S) 
est store model1_col4_dem 


***** Table 5.1 vMS *****
estout model1_bdm model1_col2_dem model1_col3_dem model1_col4_dem using ch5tbl51.txt, replace /*
*/ cells(b (star fmt(%9.3f)) se(fmt(%9.3f))) stats(N N_clust ll, fmt(%9.0f %9.0f %9.3f) label(N Countries "Log Likelihood"))  /*
*/ starlevels(* 0.10 ** 0.05 *** 0.01)


*** PREDICTED TENURES

streg pta_sign if democ_polity==1, dist(weib) cluster(ccode) anc(pta_sign) nolog nohr

** Mean Predicted Survival Time (from tenure=0), based on T5.1, C2
predictnl et_mn_col2=predict(mean time) if democ_polity==1, ci(_lb_mn _ub_mn)
tab  et_mn_col2 pta_sign /* p. 126 */

** Median Predicted Survival Time (from tenure=0), based on T5.1, C2
** Includes CIs at 95% confidence
predictnl et_med_col2=predict(median time) if democ_polity==1, ci(_lb_med _ub_med) 
tab  et_med_col2 pta_sign /* p. 126 */

*** ALL DEMOCRATIC LEADERS 
sum tenure if democ_polity==1 & pta_sign~=. , d
sum tenure if democ_polity==1 & year>=1948 & year<=2004, d

di "90th percentil of tenure in democratic polities is " r(p90) /*p 125 */
di "Mean time in office for democratic leaders is " r(mean) /*p 125 */
di "Median time in office for democratic leaders is " r(p50) /* p. 126 */

*** LEFT AND LONGEVITY
gen l = execrlc == 3
gen leftpta = pta_sign*l

streg pta_sign l leftpta if democ_polity==1, dist(weib) cluster(ccode) anc(pta_sign) nolog nohr
streg pta_sign l leftpta if democ_polity==1, dist(weib) cluster(ccode) anc(pta_sign l leftpta ) nolog nohr

